@@ -12,7 +12,7 @@ use warnings;
 
 our $VERSION;
 BEGIN {
-our $VERSION = '1.34'; # VERSION
+our $VERSION = '1.35'; # VERSION
 }
 
 use DynaLoader ();
@@ -94,16 +94,16 @@ my $Const_right = qr/^(?:const|s?refgen|gelem|die|undef|bless|anon(?:list|hash)|
                        scalar|return|last|next|redo|goto)$/x;
                                          # constant ops
 
-use vars '$File',                        # Last filename we saw.  (localised)
-         '$Line',                        # Last line number we saw.  (localised)
-         '$Collect',                     # Whether or not we are collecting
+our $File;                               # Last filename we saw.  (localised)
+our $Line;                               # Last line number we saw.  (localised)
+our $Collect;                            # Whether or not we are collecting
                                          # coverage data.  We make two passes
                                          # over conditions.  (localised)
-         '%Files',                       # Whether we are interested in files
+our %Files;                              # Whether we are interested in files
                                          # Used in runops function
-         '$Replace_ops',                 # Whether we are replacing ops
-         '$Silent',                      # Output nothing. Can be used anywhere
-         '$Self_cover';                  # Coverage of Devel::Cover
+our $Replace_ops;                        # Whether we are replacing ops
+our $Silent;                             # Output nothing. Can be used anywhere
+our $Self_cover;                         # Coverage of Devel::Cover
 
 BEGIN {
     ($File, $Line, $Collect) = ("", 0, 1);
@@ -329,7 +329,7 @@ sub import {
 
     if ($blib) {
         eval "use blib";
-        for (@INC) { $_ = $1 if /(.*)/ }  # Die tainting
+        for (@INC) { $_ = $1 if ref $_ ne 'CODE' && /(.*)/ }  # Die tainting
         push @Ignore, "^t/", '\\.t$', '^test\\.pl$';
     }
 
@@ -342,11 +342,11 @@ sub import {
 
     if (defined $Dir) {
         $Dir = $1 if $Dir =~ /(.*)/;  # Die tainting
-        chdir $Dir or die __PACKAGE__ . ": Can't chdir $Dir: $!\n";
     } else {
         $Dir = $1 if Cwd::getcwd() =~ /(.*)/;
     }
 
+    $DB = File::Spec->catdir($Dir, $DB);
     unless (mkdir $DB) {
         die "Can't mkdir $DB: $!" unless -d $DB;
     }
@@ -1289,7 +1289,7 @@ Devel::Cover - Code coverage metrics for Perl
 
 =head1 VERSION
 
-version 1.34
+version 1.35
 
 =head1 SYNOPSIS
 
