@@ -1,4 +1,4 @@
-# Copyright 2010-2017, Paul Johnson (paul@pjcj.net)
+# Copyright 2010-2019, Paul Johnson (paul@pjcj.net)
 
 # This software is free.  It is licensed under the same terms as Perl itself.
 
@@ -15,7 +15,7 @@ use warnings;
 use Exporter;
 
 our @ISA       = "Exporter";
-our @EXPORT_OK = qw(find_prove cpus nice_cpus prove_command);
+our @EXPORT_OK = qw(find_prove cpus nice_cpus njobs prove_command);
 
 sub find_prove {
     my $perl = $^X;
@@ -36,8 +36,9 @@ sub find_prove {
 
 sub cpus {
     my $cpus = 1;
-    eval { chomp ($cpus = `grep -c processor /proc/cpuinfo`); };
-    $cpus
+    eval { chomp ($cpus = `grep -c processor /proc/cpuinfo 2>/dev/null`) };
+    $cpus || eval { ($cpus) = `sysctl hw.ncpu` =~ /(\d+)/ };
+    $cpus || 1
 }
 
 sub nice_cpus {
@@ -49,6 +50,8 @@ sub nice_cpus {
     }
 }
 
+sub njobs { nice_cpus }
+
 sub prove_command {
     my $prove = find_prove or return;
     my $cpus  = nice_cpus;
@@ -81,7 +84,7 @@ Huh?
 
 =head1 LICENCE
 
-Copyright 2001-2017, Paul Johnson (paul@pjcj.net)
+Copyright 2001-2019, Paul Johnson (paul@pjcj.net)
 
 This software is free.  It is licensed under the same terms as Perl itself.
 
